@@ -1,6 +1,6 @@
 /*============================================================================
 
-  WCSLIB 4.13 - an implementation of the FITS WCS standard.
+  WCSLIB 4.14 - an implementation of the FITS WCS standard.
   Copyright (C) 1995-2012, Mark Calabretta
 
   This file is part of WCSLIB.
@@ -16,19 +16,13 @@
   more details.
 
   You should have received a copy of the GNU Lesser General Public License
-  along with WCSLIB.  If not, see <http://www.gnu.org/licenses/>.
+  along with WCSLIB.  If not, see http://www.gnu.org/licenses.
 
-  Correspondence concerning WCSLIB may be directed to:
-    Internet email: mcalabre@atnf.csiro.au
-    Postal address: Dr. Mark Calabretta
-                    Australia Telescope National Facility, CSIRO
-                    PO Box 76
-                    Epping NSW 1710
-                    AUSTRALIA
+  Direct correspondence concerning WCSLIB to mark@calabretta.id.au
 
-  Author: Mark Calabretta, Australia Telescope National Facility
-  http://www.atnf.csiro.au/~mcalabre/index.html
-  $Id: wcsutil.h,v 4.13.1.1 2012/03/14 07:40:37 cal103 Exp cal103 $
+  Author: Mark Calabretta, Australia Telescope National Facility, CSIRO.
+  http://www.atnf.csiro.au/people/Mark.Calabretta
+  $Id: wcsutil.h,v 4.14 2012/07/13 10:02:27 cal103 Exp $
 *=============================================================================
 *
 * Summary of the wcsutil routines
@@ -212,6 +206,43 @@
 * Function return value:
 *             char *    The address of hext.
 *
+*
+* wcsutil_double2str() - Translate double to string ignoring the locale
+* ---------------------------------------------------------------------
+* INTERNAL USE ONLY.
+*
+* wcsutil_double2str() converts a double to a string, but unlike sprintf it
+* ignores the locale and always uses a '.' as the decimal separator.
+*
+* Returned:
+*   buf       char *    The buffer to write the string into.
+*
+* Given:
+*   format    char *    The formatting directive, such as "%f".  This
+*                       may be any of the forms accepted by sprintf, but
+*                       should only include a formatting directive and
+*                       nothing else.
+*
+*   value     double    The value to convert to a string.
+*
+*
+* wcsutil_str2double() - Translate string to a double, ignoring the locale
+* ------------------------------------------------------------------------
+* INTERNAL USE ONLY.
+*
+* wcsutil_str2double() converts a string to a double, but unlike sscanf it
+* ignores the locale and always expects a '.' as the decimal separator.
+*
+* Given:
+*   buf       char *    The string containing the value
+*
+*   format    char *    The formatting directive, such as "%lf".  This
+*                       may be any of the forms accepted by sscanf, but
+*                       should only include a single formatting directive.
+*
+* Returned:
+*   value     double *  The double value parsed from the string.
+*
 *===========================================================================*/
 
 #ifndef WCSLIB_WCSUTIL
@@ -224,6 +255,8 @@ int  wcsutil_allEq (int nvec, int nelem, const double *first);
 void wcsutil_setAll(int nvec, int nelem, double *first);
 void wcsutil_setAli(int nvec, int nelem, int *first);
 void wcsutil_setBit(int nelem, const int *sel, int bits, int *array);
-char *wcsutil_fptr2str(int (*func)(), char hext[]);
+char *wcsutil_fptr2str(int (*func)(void), char hext[]);
+int  wcsutil_str2double(const char *buf, const char *format, double *value);
+void wcsutil_double2str(char *buf, const char *format, double value);
 
 #endif /* WCSLIB_WCSUTIL */
